@@ -1,7 +1,7 @@
 """ imports for BaseModel subclasses
 """
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 
 from .data_description import (
@@ -35,5 +35,5 @@ __all__ = [
     "Microscope",
     "OphysRig",
     "OphysSession",
-    "Axis"
+    "Axis",
 ]
