@@ -48,12 +48,12 @@ class ExampleTest(unittest.TestCase):
                         EphysProbe(
                             name="Probe A",
                             tip_targeted_structure="VISl4",
-                            targeted_ccf_coordinates=
-                                CcfCoords(ml="1",ap="1", dv='1')
-                            ,
-                            manipulator_coordinates=
-                                Coordinates3d(x="1", y="1", z="1")
-                            ,
+                            targeted_ccf_coordinates=CcfCoords(
+                                ml="1", ap="1", dv="1"
+                            ),
+                            manipulator_coordinates=Coordinates3d(
+                                x="1", y="1", z="1"
+                            ),
                             manipulator_angles=[
                                 ManipulatorAngles(name="XY", value=1),
                                 ManipulatorAngles(name="YZ", value=1),
